==> room-uikit-web-vue3-1.0.3.tgz: package/src/TUIRoom/extension/RoomMessageCard/roomMessageCard.ts <==
import { ChatExtension, RoomState } from '../chatExtension';
import { Profile } from '@tencentcloud/chat';

// 渲染卡片需要用到 isRoomMessage、isRoomCreateByMe、userList、isEnterRoom
export interface MessageData {
  isInnerRoom: boolean
  isRoomMessage: boolean
  isRoomCreateByMe: boolean
  isMessageFromMe: boolean
  roomId: string
  inviter: {
    faceUrl: string
    userId: string
    nickName: string
  }
  roomState: RoomState
  userList: Array<{ faceUrl: string; nickName: string; userId: string }>
  myProfile: Profile
}
// ChatExtension 提供基础功能 编辑消息 发送消息 消息上屏等
// RoomMessageCard 实现业务功能 发起会议、加入会议、离开会议等

export class RoomMessageCard {
  private chatExtension = ChatExtension.getInstance();
  public messageData: MessageData = {
    isInnerRoom: false,
    isRoomMessage: false,
    isRoomCreateByMe: false,
    isMessageFromMe: false,
    roomId: '',
    inviter: {
      faceUrl: '',
      userId: '',
      nickName: '',
    },
    roomState: RoomState.CREATED,
    userList: [],
    myProfile: {} as Profile,
  };

  public initialize(message: any) {
    this.handleMessage(message);
  }

  public destroy() {}

  // 获取卡片信息
  private handleMessage(message: any) {
    const currentUser = ChatExtension.chatContext?.userID;
    const messagePayload = this.parseMessageData(message);
    if (messagePayload.businessID !== 'ROOM_INVITE_ACTION') return;
    const {
      businessID,
      data: { owner, roomId, inviter, roomState, userList },
    } = messagePayload;
    const isRoomDestroyed = roomState === RoomState.DESTROYED;
    const isInnerRoom = userList.some(u => u.userId === currentUser) && !isRoomDestroyed;
    if (!ChatExtension.isInnerRoom && !isRoomDestroyed) {
      // 因为存在多个 message 卡片，因此如果已经在会议则跳过这个步骤
      ChatExtension.isInnerRoom = isInnerRoom;
    }
    if (currentUser === owner && isInnerRoom) {
      ChatExtension.message = message;
      ChatExtension.messagePayload = messagePayload;
    }
    // todo 如何判断是否是room的组定义消息
    this.messageData = {
      isInnerRoom,
      isRoomMessage: businessID === 'ROOM_INVITE_ACTION',
      isRoomCreateByMe: owner === currentUser,
      isMessageFromMe: message.from === currentUser,
      roomId,
      inviter,
      roomState,
      userList,
      myProfile: this.chatExtension.myProfile,
    };
  }

  public parseMessageData(message: any) {
    return this.chatExtension.parseMessageData(message);
  }
}

export const roomMessageCard = new RoomMessageCard();

==> room-uikit-web-vue3-1.7.0.tgz: package/src/TUIRoom/extension/RoomMessageCard/roomMessageCard.ts <==
import { ChatExtension, RoomState } from '../chatExtension';
import { Message, Profile } from '@tencentcloud/chat';

// 渲染卡片需要用到 isRoomMessage、isRoomCreateByMe、userList、isEnterRoom
export interface MessageData {
  isInnerRoom: boolean
  isRoomMessage: boolean
  isRoomCreateByMe: boolean
  isMessageFromMe: boolean
  roomId: string
  roomState: RoomState
  userList: Array<{ faceUrl: string; nickName: string; userId: string }>
  myProfile: Profile
  ownerName: string
  owner: string
}
// ChatExtension 提供基础功能 编辑消息 发送消息 消息上屏等
// RoomMessageCard 实现业务功能 发起会议、加入会议、离开会议等

export class RoomMessageCard {
  private chatExtension = ChatExtension.getInstance();
  public messageData: MessageData = {
    isInnerRoom: false,
    isRoomMessage: false,
    isRoomCreateByMe: false,
    isMessageFromMe: false,
    roomId: '',
    roomState: RoomState.CREATED,
    userList: [],
    myProfile: {} as Profile,
    ownerName: '',
    owner: '',
  };

  public initialize(message: Message) {
    this.handleMessage(message);
  }

  public destroy() {}

  // 获取卡片信息
  private handleMessage(message: Message) {
    const currentUser = ChatExtension.chatContext?.userID;
    const messagePayload = this.parseMessageData(message);
    if (messagePayload.businessID !== 'group_room_message') return;
    const {
      businessID,
      owner,
      roomId,
      roomState,
      userList,
      ownerName,
    } = messagePayload;
    const isRoomDestroyed = roomState === RoomState.DESTROYED;
    const isInnerRoom = userList.some(u => u.userId === currentUser) && !isRoomDestroyed;
    if (!isRoomDestroyed) {
      // 因为存在多个 message 卡片，因此如果已经在会议则跳过这个步骤
      ChatExtension.isInnerRoom = isInnerRoom;
    }
    if (currentUser === owner && isInnerRoom) {
      ChatExtension.message = message;
      ChatExtension.messagePayload = messagePayload;
    }
    // todo 如何判断是否是room的组定义消息
    this.messageData = {
      isInnerRoom,
      isRoomMessage: businessID === 'group_room_message',
      isRoomCreateByMe: owner === currentUser,
      isMessageFromMe: message.from === currentUser,
      roomId,
      roomState,
      userList,
      myProfile: this.chatExtension.myProfile,
      ownerName,
      owner,
    };
  }

  public parseMessageData(message: Message) {
    return this.chatExtension.parseMessageData(message);
  }
}

export const roomMessageCard = new RoomMessageCard();
